import os
from datetime import datetime

# 检测姓名是否合理（以字母或汉字开头，且不能全是数字）
def validate_name(name):
    if not name.strip():  # 检查姓名是否为空（去掉首尾空格后是否为空）
        print("姓名不能为空！")
        return False
    if name.isdigit():  # 检查姓名是否全是数字
        print("姓名不能全是数字！")
        return False
    # 检查是否以字母或汉字开头
    if not name[0].isalpha():  # 检查姓名的第一个字符是否是字母或汉字
        print("姓名必须以字母或汉字开头！")
        return False
    return True  # 如果以上检查都通过，返回 True

# 检测年龄是否为有效数字
def validate_age(age):
    if not age.isdigit():  # 检查年龄是否是数字
        print("年龄必须是一个数字！")
        return False
    age = int(age)  # 将年龄转换为整数
    if age < 0 or age > 120:  # 检查年龄是否在 0 到 120 之间
        print("年龄必须在 0 到 120 之间！")
        return False
    return True  # 如果以上检查都通过，返回 True

# 检测生日格式和合理性
def validate_birthday(birthday, age):
    try:
        # 检查日期格式是否为 xxxx/xx/xx
        date = datetime.strptime(birthday, "%Y/%m/%d")  # 尝试将字符串转换为日期对象
        current_time = datetime.now()  # 获取当前时间

        # 检查年份是否合理
        if date.year < 1900 or date.year > current_time.year:  # 检查年份是否在 1900 到当前年份之间
            print(f"年份必须在 1900 到 {current_time.year} 之间！")
            return False

        # 检查月份是否合理
        if date.month < 1 or date.month > 12:  # 检查月份是否在 1 到 12 之间
            print("月份必须在 1 到 12 之间！")
            return False

        # 检查日期是否合理
        if date.day < 1 or date.day > 31:  # 检查日期是否在 1 到 31 之间
            print("日期必须在 1 到 31 之间！")
            return False

        # 检查 2 月的日期是否合理
        if date.month == 2:  # 如果是 2 月
            if (date.year % 4 == 0 and date.year % 100 != 0) or (date.year % 400 == 0):  # 判断是否是闰年
                if date.day > 29:  # 闰年 2 月最多 29 天
                    print(f"{date.year} 年是闰年,2 月最多 29 天！")
                    return False
            else:
                if date.day > 28:  # 非闰年 2 月最多 28 天
                    print(f"{date.year} 年不是闰年,2 月最多 28 天！")
                    return False

        # 检查生日是否超过当前时间
        if date > current_time:  # 检查生日是否超过当前时间
            print("生日不能超过当前时间！")
            return False

        # 检查年龄和生日年份是否匹配
        expected_birth_year = current_time.year - int(age)  # 根据年龄计算预期的出生年份
        if date.year != expected_birth_year:  # 检查用户输入的年份是否与预期一致
            print(f"根据年龄 {age} 岁，出生年份应为 {expected_birth_year} 年，请检查输入！")
            return False

        return True  # 如果以上检查都通过，返回 True
    except ValueError:  # 如果日期格式不正确，捕获异常
        print("生日格式不正确，请输入 xxxx/xx/xx 格式！")
        return False

# 获取用户输入
while True:  # 循环直到输入正确的姓名
    user_name = input("请输入你的姓名：")
    if validate_name(user_name):  # 调用 validate_name 函数检测姓名
        break  # 如果姓名正确，退出循环

while True:  # 循环直到输入正确的年龄
    user_age = input("请输入你的年龄：")
    if validate_age(user_age):  # 调用 validate_age 函数检测年龄
        break  # 如果年龄正确，退出循环

while True:  # 循环直到输入正确的生日
    user_sr = input("生日(xxxx/xx/xx):")
    if validate_birthday(user_sr, user_age):  # 调用 validate_birthday 函数检测生日
        break  # 如果生日正确，退出循环

# 将用户输入信息写入文件（覆盖模式）
with open("1.txt", "w", encoding="UTF-8") as f:  # 打开文件，使用覆盖模式
    f.write(f"用户姓名：{user_name}\n")  # 写入姓名
    f.write(f"用户年龄：{user_age}\n")  # 写入年龄
    f.write(f"用户生日：{user_sr}\n")  # 写入生日

# 使用 f-字符串进行格式化输出
print(f"姓名：{user_name}\n年龄:{user_age}\n生日:{user_sr}")  # 打印用户输入的信息
