# 定义一个函数 validate_name，用于验证用户输入的姓名是否符合要求
def validate_name(name):
    # 检查姓名是否为空（去掉首尾空格后是否为空）
    if not name.strip():
        # 如果姓名为空，打印提示信息
        print("姓名不能为空！")
        # 返回 False，表示验证失败
        return False
    # 检查姓名是否全是数字
    if name.isdigit():
        # 如果姓名全是数字，打印提示信息
        print("姓名不能全是数字！")
        # 返回 False，表示验证失败
        return False
    # 检查姓名的第一个字符是否是字母或汉字
    if not name[0].isalpha():
        # 如果姓名的第一个字符不是字母或汉字，打印提示信息
        print("姓名必须以字母或汉字开头！")
        # 返回 False，表示验证失败
        return False
    # 如果以上检查都通过，返回 True，表示验证成功
    return True


# 定义一个函数 validate_number，用于验证用户输入的数值是否符合要求
def validate_number(input_value, field_name):
    try:
        # 尝试将输入值转换为浮点数
        float(input_value)
        # 如果转换成功，返回 True，表示验证成功
        return True
    except ValueError:
        # 如果转换失败（输入的不是数字），打印提示信息
        print(f"{field_name}必须是一个数字！")
        # 返回 False，表示验证失败
        return False


# 验证姓名
# 使用一个无限循环，直到用户输入正确的姓名
while True:
    # 提示用户输入姓名
    user_name = input("请输入你的姓名：")
    # 调用 validate_name 函数验证姓名
    if validate_name(user_name):
        # 如果验证成功，退出循环
        break

# 验证体重
# 使用一个无限循环，直到用户输入正确的体重
while True:
    # 提示用户输入体重
    user_weight_input = input("请输入你的体重(kg):")
    # 调用 validate_number 函数验证体重
    if validate_number(user_weight_input, "体重"):
        # 如果验证成功，将输入的体重转换为浮点数
        user_weight = float(user_weight_input)
        # 退出循环
        break

# 验证身高
# 使用一个无限循环，直到用户输入正确的身高
while True:
    # 提示用户输入身高
    user_height_input = input("请输入你的身高(m):")
    # 调用 validate_number 函数验证身高
    if validate_number(user_height_input, "身高"):
        # 如果验证成功，将输入的身高转换为浮点数
        user_height = float(user_height_input)
        # 退出循环
        break

# 计算 BMI
# BMI 公式：BMI = 体重(kg) / 身高(m)^2
bmi = user_weight / (user_height**2)

with open("bmi.txt","w",encoding="utf-8") as f:
    f.write(f"用户姓名:{user_name}\n")
    f.write(f"用户体重:{user_weight}\n")
    f.write(f"用户身高:{user_height}\n")
    f.write(f"用户BMI:{bmi}\n")


# 输出结果
# 打印用户的姓名、体重、身高和计算出的 BMI 值
# BMI 值保留两位小数
print(f"姓名: {user_name}, 体重: {user_weight}kg, 身高: {user_height}m, BMI: {bmi:.2f}")